==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/GetTileImageUriArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescription } from "./GetTileImageUriArgsDescription";
/**
 * @hidden
 */
var GetTileImageUriArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GetTileImageUriArgsDescriptionMetadata, _super);
    function GetTileImageUriArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GetTileImageUriArgsDescriptionMetadata.b = function (a) {
        if (GetTileImageUriArgsDescriptionMetadata.a == null) {
            GetTileImageUriArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GetTileImageUriArgsDescriptionMetadata.c(GetTileImageUriArgsDescriptionMetadata.a);
        }
        if (a.k(GetTileImageUriArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(GetTileImageUriArgsDescriptionMetadata.a);
    };
    GetTileImageUriArgsDescriptionMetadata.c = function (a) {
        a.item("TileLevel", "Number:int");
        a.item("TilePositionX", "Number:int");
        a.item("TilePositionY", "Number:int");
        a.item("TileImageUri", "String");
    };
    GetTileImageUriArgsDescriptionMetadata.d = function (a) {
        GetTileImageUriArgsDescriptionMetadata.b(a);
        a.ad("GetTileImageUriArgs", function () { return new GetTileImageUriArgsDescription(); });
        a.ac("GetTileImageUriArgs", GetTileImageUriArgsDescriptionMetadata.a);
    };
    GetTileImageUriArgsDescriptionMetadata.$t = markType(GetTileImageUriArgsDescriptionMetadata, 'GetTileImageUriArgsDescriptionMetadata');
    GetTileImageUriArgsDescriptionMetadata.a = null;
    return GetTileImageUriArgsDescriptionMetadata;
}(Base));
export { GetTileImageUriArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/GetTileImageUriArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescription } from "./GetTileImageUriArgsDescription";
/**
 * @hidden
 */
var GetTileImageUriArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GetTileImageUriArgsDescriptionMetadata, _super);
    function GetTileImageUriArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GetTileImageUriArgsDescriptionMetadata.b = function (a) {
        if (GetTileImageUriArgsDescriptionMetadata.a == null) {
            GetTileImageUriArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GetTileImageUriArgsDescriptionMetadata.c(GetTileImageUriArgsDescriptionMetadata.a);
        }
        if (a.k(GetTileImageUriArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(GetTileImageUriArgsDescriptionMetadata.a);
    };
    GetTileImageUriArgsDescriptionMetadata.c = function (a) {
        a.item("TileLevel", "Number:int");
        a.item("TilePositionX", "Number:int");
        a.item("TilePositionY", "Number:int");
        a.item("TileImageUri", "String");
    };
    GetTileImageUriArgsDescriptionMetadata.d = function (a) {
        GetTileImageUriArgsDescriptionMetadata.b(a);
        a.ae("GetTileImageUriArgs", function () { return new GetTileImageUriArgsDescription(); });
        a.ad("GetTileImageUriArgs", GetTileImageUriArgsDescriptionMetadata.a);
    };
    GetTileImageUriArgsDescriptionMetadata.$t = markType(GetTileImageUriArgsDescriptionMetadata, 'GetTileImageUriArgsDescriptionMetadata');
    GetTileImageUriArgsDescriptionMetadata.a = null;
    return GetTileImageUriArgsDescriptionMetadata;
}(Base));
export { GetTileImageUriArgsDescriptionMetadata };
